Shoehorn
========

Shoehorning structured logs into or out of standard library logging since 2016.

Currently just pipes into standard library. No docs.

To-Do
=====

- Standard Library Handler to pipe into shoehorn.

- Changes to StandardLibraryTarget to allow both standard library to Shoehorn
  and shoehorn to standard library.

- Stream target.

- Filter target example.

- Target stacking pattern.

- JSON serialiser.

- LTSV serializer.
